import { DependencyList } from "react";
import { DebounceOptions } from "perfect-debounce";
export const depsChanged: (a: DependencyList, b: DependencyList) => boolean;
export const shallowMerge: <T extends UnknownRecord, U extends T | Partial<T> | undefined>(init: T, ...objs: U[]) => T;
export type UnknownRecord = Record<string | number | symbol, unknown>;
/**
 * `useAsyncCb` provides a sync callback for an async function
 * along with helpers to track the state.
 */
export const useAsyncCb: <A extends unknown[], R>(fnAsync: (...args: A) => Promise<R>, onError?: (err: Error) => void) => (boolean | R | Error | ((...args: A) => void) | undefined)[];
/**
 * `useAutoReducer` gives a preconfigured `useReducer` hook which is enough
 * for most needs. The `state` is initialized to the given value, and the
 * `dispatch` function accepts fragments of `state` which are merged in.
 */
export const useAutoReducer: <S extends UnknownRecord>(initState: S) => [S, import("react").Dispatch<Partial<S> | ((prev: S) => Partial<S>)>];
/**
 * `useCurrentRef` escapes closures. `ref.current` will always be
 * the latest `val` even if `ref` is captured.
 */
export const useCurrentRef: <T>(val: T) => import("react").MutableRefObject<T>;
/**
 * `useDebounce` gives a value that delays updates to `val` by the duration `dur`.
 */
export const useDebounce: <T>(val: T, dur?: number) => T;
/**
 * `useDebounceFn` consolidates multiple calls tp `fn` within duration `dur` into one.
 * Calls the given function immediately, use `opts` to change behavior.
 */
export const useDebounceFn: <F extends (...args: Parameters<F>) => ReturnType<F>>(fn: F, dur?: number, opts?: DebounceOptions) => (...args: Parameters<F>) => Promise<ReturnType<F>>;
/**
 * `useMutexFn` returns a callback that allows one call to `fn` and
 * ignores all subsequent calls until it completes.
 */
export const useMutexFn: <F extends (...args: Parameters<F>) => Promise<void>>(fn: F) => (...args: Parameters<F>) => Promise<void>;
/**
 * `useStaticMutexFn` is the same as `useMutexFn`, but the returned ref is wrapped
 * with `useStaticFn` instead of the standard `useCallback`.
 */
export const useStaticMutexFn: <F extends (...args: Parameters<F>) => Promise<void>>(fn: F) => (...args: Parameters<F>) => Promise<void>;
/**
 * `useStaticMemo` will _never_ recompute the value unless `deps` change,
 * even if React thinks it'd be funny.
 */
export const useStaticMemo: <T>(gen: () => T, deps?: DependencyList) => T;
/**
 * `useStaticFn` gives a ref to `fn` which always calls the latest `fn`,
 * but won't trigger rerenders if `fn` changes.
 */
export const useStaticFn: <F extends (...args: Parameters<F>) => ReturnType<F>>(fn: F) => F;
/**
 *  `useStaticEffect` will be called once and only once,
 * without complaints about incomplete deps arrays.
 */
export const useStaticEffect: (fn: () => void) => void;

//# sourceMappingURL=index.d.ts.map
